===============================
networking-mlnx
===============================

Networking MLNX contains the Mellanox vendor code for Openstack Neutron

*   Free software: Apache license
*   Documentation: https://wiki.openstack.org/wiki/Mellanox-Neutron-ML2
*   Source: https://github.com/stackforge/networking-mlnx
*   Bugs: https://bugs.launchpad.net/networking-mlnx
